@@ -116,7 +116,7 @@ class reachability(object):
         try:
             points = self.compute_convex_hull(unique_vec[:, 0], unique_vec[:, 1])
         except:
-            None
+            points=np.empty([1, 2])
         return [points[:, 0], points[:, 1]], unique_vec
 
     """
